# Experiment 2 analysis
# 6/21/2018
# Zachary Wallmark

# load libraries
library(readxl)
library(dplyr)
library(ggplot2)
library(ez)
library(psych)
library(pastecs)

# import long-form (precleaned in Excel)
FINAL <- read_excel("~/Desktop/Timbre_Stroop/EX1_Pilot/FINAL.xlsx", 
                    col_types = c("numeric", "text", "text", 
                                  "text", "numeric", "numeric", "blank", 
                                  "blank", "blank", "blank", "blank", 
                                  "blank"))
View(FINAL)

# prep
FINAL$Subject = factor(FINAL$Subject)
FINAL$Group = factor(FINAL$Group)
FINAL$Block = factor(FINAL$Block)
FINAL$Modality = factor(FINAL$Modality)
FINAL$Stim = factor(FINAL$Stim)

# subdivide by Block (imbalance in stim #)
Natural = FINAL %>% filter(Block == "natural")
Synth = FINAL %>% filter(Block == "synth")

# reliability analysis (by Block/Modality): alpha
nat_vis <- read_excel("~/Desktop/Timbre_Stroop/EX1_Pilot/Nat_vis_wide.xlsx")
alpha(nat_vis)
nat_tac <- read_excel("~/Desktop/Timbre_Stroop/EX1_Pilot/nat_tactile.xlsx")
alpha(nat_tac)
synth_vis <- read_excel("~/Desktop/Timbre_Stroop/EX1_Pilot/synth_vis.xlsx")
alpha(synth_vis)
synth_tactile <- read_excel("~/Desktop/Timbre_Stroop/EX1_Pilot/synth_tactile.xlsx")
alpha(synth_tactile)


# Mixed-effects modeling for Natural and Synth (including ANOVA outputs)
nat_mod = lmer(Value ~ Group*Modality*Stim + (1|Subject), data = Natural)
summary(nat_mod)
anova(nat_mod) # for ANOVA style output
Anova(nat_mod) # for Wald-chi^2

synth_mod = lmer(Value ~ Group*Modality*Stim + (1|Subject), data = Synth)
summary(synth_mod)
anova(synth_mod) 
Anova(synth_mod) # for Wald-chi^2

# check effect sizes of models
r2.corr.mer <- function(m) {
  lmfit <-  lm(model.response(model.frame(m)) ~ fitted(m))
  summary(lmfit)$r.squared
}
r2.corr.mer(nat_mod)
r2.corr.mer(synth_mod)

# Describe
by(Natural$Value, Natural$Modality, stat.desc)
by(Synth$Value, Synth$Modality, stat.desc)

# 2-way interactions between modality and group
interaction.plot(Natural$Group, Natural$Modality, Natural$Value, fun = mean)
interaction.plot(Synth$Group, Synth$Modality, Synth$Value, fun = mean)

# EXAMPLE of stim selection procedure: Sort descending
t_nat = Natural %>%
  filter(Modality == "visual") %>%
  group_by(Stim) %>%
  summarise(mean = mean(Value), stdev = sd(Value)) %>%
  arrange(mean)
t_nat$i = c(1:50) # order index
t_nat$name = c('Archlute', 'Tuba', 'Oboe', 'Crumhorn', 'T Sax (growl)', 'Trombone (mute)', 'T recorder', 'Bassoon', rep(NA, 34), 'Cornetto','Viol (bass)','Trumpet (harmon)','Shawm','Trumpet','Guitar','Horn (mute)','Eng Horn')

# Plot mean intensity score: Nat-visual
ggplot(t_nat, aes(x = i, y = mean, fill = i > 42 | i < 9)) + 
  scale_fill_manual(values = c('gray82', 'lightcoral')) +
  geom_bar(stat = "identity") +
  scale_y_continuous("Average intensity rating") +
  scale_x_continuous("Natural stimuli") +
  theme_bw() +
  geom_errorbar(aes(ymin = mean - stdev, ymax = mean + stdev), width = 0.2) +
  theme(legend.position="none") +
  theme(axis.title.x=element_text(size=10)) +
  theme(axis.title.y=element_text(size=10)) +
  geom_text(aes(label = name), position = position_stack(vjust=0.25), angle =90, size = 2) +
  coord_fixed(ratio = 5)
  ggsave("nat_visual.eps", dpi = 400)
  
  # Principal Component Regression
  library(pls)
  
  # trim data (for brightness); for roughness/intensity use below
  #temp <- select_(nat, -1, -3, -4)
  #temp <- select_(nat, -1, -2, -4)
  temp <- temp[, -c(1:3)]
  
  # PCR modeling 
  pcr_model_intensity <- pcr(Intensity~., data = temp, scale = TRUE, validation = "LOO", jackknife = T)
  summary(pcr_model_intensity)
  loadings(pcr_model_intensity)
  compnames(pcr_model_intensity, explvar = TRUE)
  
  # diagnostic plots
  validationplot(pcr_model_intensity, val.type = "R2")
  validationplot(pcr_model_intensity) # for RMSE
  predplot(pcr_model_intensity, ncomp = 3, line = T, pch = 16)
  loadingplot(pcr_model_intensity, comps = 1:3, scatter = T, labels = names(temp))
  jack.test(pcr_model_intensity, ncomp = 3)
  
  #Validated model: 3 PCs
  pcr_model_3 <- pcr(Intensity~., data = temp, ncomp = 3, scale = TRUE, validation = "LOO", jackknife = T)
  summary(pcr_model_3)
  
  

